@@ -51,6 +51,7 @@ from ._pmap import PersistentMap, \
                    MapTimestampStringFlatBuffers, \
                    MapTimestampUuidFlatBuffers, \
                    MapTimestampUuidStringFlatBuffers, \
+                   MapUuidTimestampUuidFlatBuffers, \
                    MapTimestampUuidCbor, \
                    MapUuidTimestampUuid, \
                    MapUuidStringUuid, \
@@ -61,7 +62,9 @@ from ._pmap import PersistentMap, \
                    MapUuidUuidSet, \
                    MapUuidUuidUuid, \
                    MapUuidTimestampBytes32, \
+                   MapUuidUuidFlatBuffers, \
                    MapUuidUuidStringFlatBuffers, \
+                   MapUuidStringFlatBuffers, \
                    MapStringString, \
                    MapStringOid, \
                    MapStringOidOid, \
@@ -89,6 +92,7 @@ from ._pmap import PersistentMap, \
                    MapOidTimestampOid, \
                    MapOidTimestampFlatBuffers, \
                    MapOidTimestampStringOid, \
+                   MapUint16UuidTimestampFlatBuffers, \
                    MapBytes32Uuid, \
                    MapBytes32Timestamp, \
                    MapBytes32Bytes32, \
@@ -145,9 +149,11 @@ __all__ = (
     'MapTimestampFlatBuffers',
     'MapTimestampStringFlatBuffers',
     'MapTimestampUuidStringFlatBuffers',
+    'MapUuidTimestampUuidFlatBuffers',
     'MapUuidBytes20Uint8FlatBuffers',
     'MapUuidBytes20Uint8UuidFlatBuffers',
     'MapUuidBytes20Bytes20Uint8UuidFlatBuffers',
+    'MapUint16UuidTimestampFlatBuffers',
 
     # UUID (uint128) based pmap types for indexes
     'MapUuidUuid',
@@ -160,6 +166,8 @@ __all__ = (
     'MapUuidStringOid',
 
     # UUID-UUID based pmap types
+    'MapUuidUuidFlatBuffers',
+    'MapUuidStringFlatBuffers',
     'MapUuidUuidCbor',
     'MapUuidUuidUuid',
     'MapUuidTimestampUuid',
