@@ -82,6 +82,7 @@ def dt_to_bytes(dt):
     assert isinstance(dt, np.datetime64)
 
     data = bytearray(dt.tobytes())
+    # FIXME: this must depend on host CPU arch
     data.reverse()
     return bytes(data)
 
@@ -96,6 +97,7 @@ def bytes_to_dt(data):
     assert type(data) == bytes
 
     data = bytearray(data)
+    # FIXME: this must depend on host CPU arch
     data.reverse()
     dt = np.frombuffer(bytes(data), dtype='datetime64[ns]')[0]
     return dt
@@ -377,6 +379,35 @@ class _UuidUuidKeysMixin(object):
         return uuid.UUID(bytes=data1), uuid.UUID(bytes=data2)
 
 
+class _Uint16UuidTimestampKeysMixin(object):
+    @staticmethod
+    def new_key():
+        return random.randint(0, 2**16), uuid.uuid4(), np.datetime64(time_ns(), 'ns')
+
+    def _serialize_key(self, key1_key2_key3):
+        assert type(key1_key2_key3) == tuple and len(key1_key2_key3) == 3
+        key1, key2, key3 = key1_key2_key3
+
+        if key1 is None:
+            key1 = 0
+        if key2 is None:
+            key2 = uuid.UUID(bytes=b'\x00' * 16)
+        if key3 is None:
+            key3 = np.datetime64(0, 'ns')
+
+        assert type(key1) == int and key1 >= 0 and key1 < 2**16
+        assert isinstance(key2, uuid.UUID)
+        assert isinstance(key3, np.datetime64)
+
+        return struct.pack('H', key1) + key2.bytes + dt_to_bytes(key3)
+
+    def _deserialize_key(self, data):
+        assert type(data) == bytes and len(data) == (2 + 16 + 8)
+
+        data1, data2, data3 = data[0:2], data[2:18], data[18:26],
+        return struct.unpack('H', data1), uuid.UUID(bytes=data2), bytes_to_dt(data3)
+
+
 class _UuidBytes20Uint8KeysMixin(object):
     @staticmethod
     def new_key():
@@ -524,6 +555,40 @@ class _TimestampUuidKeysMixin(object):
         return key1, key2
 
 
+class _UuidTimestampUuidKeysMixin(object):
+    @staticmethod
+    def new_key():
+        return uuid.uuid4(), np.datetime64(time_ns(), 'ns'), uuid.uuid4()
+
+    def _serialize_key(self, key1_key2_key3):
+        assert type(key1_key2_key3) == tuple and len(key1_key2_key3) == 3
+        key1, key2, key3 = key1_key2_key3
+
+        if key1 is None:
+            key1 = uuid.UUID(bytes=b'\x00' * 16)
+        if key2 is None:
+            key2 = np.datetime64(0, 'ns')
+        if key3 is None:
+            key3 = uuid.UUID(bytes=b'\x00' * 16)
+
+        assert isinstance(key1, uuid.UUID)
+        assert isinstance(key2, np.datetime64)
+        assert isinstance(key3, uuid.UUID)
+
+        return key1.bytes + dt_to_bytes(key2) + key3.bytes
+
+    def _deserialize_key(self, data):
+        assert type(data) == bytes
+        assert len(data) == 32
+
+        data1, data2, data3 = data[0:16], data[16:24], data[24:32]
+
+        key1 = uuid.UUID(bytes=data1)
+        key2 = bytes_to_dt(data2)
+        key3 = uuid.UUID(bytes=data3)
+        return key1, key2, key3
+
+
 class _TimestampUuidStringKeysMixin(object):
     @staticmethod
     def new_key():
